@@ -6,11 +6,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(DARWIN)
-#include <sys/malloc.h>
-#else
-#include <malloc.h>
-#endif
 #include <ctype.h>
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -253,9 +248,7 @@ void loadlgf(int mode)
 		  strptr->type = TEXT_STRING;
 		  strptr->data.string = (char *)malloc(1 + strlen(tstrp));
 		  strcpy(strptr->data.string, tstrp);
-#ifdef SCHEMA
 		  (*newlabel)->pin = NORMAL;
-#endif
 	       }
             }}
 	    break;
@@ -285,7 +278,6 @@ void loadlgf(int mode)
 	       (*newwire)->width = 1.0;
 	       (*newwire)->style = UNCLOSED;
 	       (*newwire)->color = DEFAULTCOLOR;
-	       (*newwire)->num_params = 0;
 	       (*newwire)->passed = NULL;
 	       tmppnts = (*newwire)->points;
 	       tmppnts->x = xmat(pvalx);
@@ -336,7 +328,6 @@ void loadlgf(int mode)
 	       (*newpoly)->width = 1.0;
 	       (*newpoly)->number = 4;
                (*newpoly)->points = (pointlist) malloc(4 * sizeof(XPoint));
-	       (*newpoly)->num_params = 0;
 	       (*newpoly)->passed = NULL;
 
                newpoints = (*newpoly)->points;
@@ -405,7 +396,6 @@ void loadlgf(int mode)
 		  (*newinst)->scale = 1.0;
 		  (*newinst)->color = DEFAULTCOLOR;
 		  (*newinst)->params = NULL;
-	          (*newinst)->num_params = 0;
 	          (*newinst)->passed = NULL;
 
 		  if (pvalx2 & 0x01) pvalx2 ^= 0x02;
@@ -439,12 +429,10 @@ void loadlgf(int mode)
 			   labeldefaults(*newlabel, False, (*newinst)->position.x,
 				(*newinst)->position.y);
 			   (*newlabel)->color = DEFAULTCOLOR;
-#ifdef SCHEMA
 		  	   if (areastruct.schemon){
 			      (*newlabel)->pin = LOCAL;
 			      (*newlabel)->color = LOCALPINCOLOR;
 		  	   }
-#endif
 			   if (!strcmp(tmpstring, "TO"))
 			      (*newlabel)->position.x += ((flip) ? 48 : -48);
 			   else
