@@ -246,9 +246,7 @@ static PyObject *xc_new(PyObject *self, PyObject *args)
    } 
    topobject->parts++;
    incr_changes(topobject);
-#ifdef SCHEMA
-   topobject->valid = False;
-#endif
+   invalidate_netlist(topobject);
 
    return PyInt_FromLong((long)(*newgen));
 }
@@ -883,7 +881,6 @@ static PyObject *xc_reset()
    return PyInt_FromLong(0L);
 }
 
-#ifdef SCHEMA
 /*--------------------------------------------------------------*/
 /* Get a netlist						*/
 /*--------------------------------------------------------------*/
@@ -896,13 +893,9 @@ static PyObject *xc_netlist()
 {
    PyObject *rdict = NULL;
 
-   if (checkvalid(topobject) == -1) {
-      if (cleartraversed(topobject, 0) == -1)
-         PyErr_SetString(PyExc_TypeError, "Error:  Check circuit for infinite recursion.");
-      else {
-         destroynets();
-         createnets(areastruct.thisinstance);
-      }
+   if (updatenets(areastruct.topinstance) <= 0) {
+      PyErr_SetString(PyExc_TypeError, "Error:  Check circuit for infinite recursion.");
+      return NULL;
    }
 
    subindex = 1;
@@ -911,7 +904,6 @@ static PyObject *xc_netlist()
    PyDict_SetItem(rdict, PyString_FromString("circuit"), pytoplevel(topobject));
    return rdict;
 }
-#endif
 
 /*--------------------------------------------------------------*/
 /* Load the specified file					*/
@@ -1105,10 +1097,8 @@ static PyObject *xc_getattr(PyObject *self, PyObject *args)
 		PyFloat_FromDouble((double)TOLABEL(gelem)->scale));
 	 PyDict_SetItem(rdict, PyString_FromString("justify"),
 		PyInt_FromLong((long)TOLABEL(gelem)->justify));
-#ifdef SCHEMA
 	 PyDict_SetItem(rdict, PyString_FromString("pin"),
 		PyInt_FromLong((long)TOLABEL(gelem)->pin));
-#endif
 	 lstr = PyGetStringParts(TOLABEL(gelem)->string);
 
 	 PyDict_SetItem(rdict, PyString_FromString("string"), lstr);
@@ -1348,11 +1338,9 @@ static PyObject *xc_setattr(PyObject *self, PyObject *args)
 	    freelabel(TOLABEL(gelem)->string);
 	    TOLABEL(gelem)->string = PySetStringParts(dval);
 	 }
-#ifdef SCHEMA
 	 if ((dval = PyDict_GetItemString(attrdict, "pin")) != NULL) {
 	    TOLABEL(gelem)->pin = PyInt_AsLong(dval);
 	 }
-#endif
 	 break;
       case ARC:
 	 if ((dval = PyDict_GetItemString(attrdict, "start angle")) != NULL) {
@@ -1523,12 +1511,10 @@ static PyObject *xc_set(PyObject *self, PyObject *args)
          xobjs.pagelist[cpage]->orient = 0;  /* Portrait */
    }
 
-#ifdef SCHEMA
    else if (!strcmp(sarg1, "xschema") || !strcmp(sarg1, "schema")) {
       areastruct.schemon = a;
       doxschema(OptionsEnableXSchemaButton, 1, NULL);
    }
-#endif
 #ifdef HAVE_XPM
    else if (!strcmp(sarg1, "toolbar")) {
       areastruct.toolbar_on = a;
@@ -1960,9 +1946,7 @@ static PyMethodDef xc_methods[] = {
 #ifdef HAVE_XPM
    {"newtool",		xc_newtool,	1},
 #endif
-#ifdef SCHEMA
    {"netlist",		xc_netlist,	1},
-#endif
    {NULL,	NULL}			/* sentinel */
 };
 
@@ -2122,14 +2106,13 @@ void loadrcfile()
       addnewcolorentry(xc_alloccolor("Brown"));
    }  
 
-#ifdef SCHEMA
    /* These colors must be enabled whether or not colors are overridden, */
    /* because they are needed by the schematic capture system.		 */
 
    addnewcolorentry(xc_getlayoutcolor(LOCALPINCOLOR));
    addnewcolorentry(xc_getlayoutcolor(GLOBALPINCOLOR));
    addnewcolorentry(xc_getlayoutcolor(INFOLABELCOLOR));
-#endif
+   addnewcolorentry(xc_getlayoutcolor(RATSNESTCOLOR));
    addnewcolorentry(xc_getlayoutcolor(BBOXCOLOR));
 
    if (!(flags & KEYOVERRIDE))
